Code coverage report for js/widgets/SingleLineTextInputWidget.tsx

# All files / js/widgets SingleLineTextInputWidget.tsx

66.67% Statements 2/3
100% Branches 0/0
0% Functions 0/1
66.67% Lines 2/3

Press n or j to go to the next uncovered block, b, p or k for the previous block.

    1
    2
    3
    4
    5
    6
    7
    8
    9
    10
    11
    12
    13
    141x

    1x

     import React from "react";
    import { WidgetProps } from "./types";
    import InputWidgetBase from "./InputWidgetBase";

    export function SingleLineTextInputWidget(props: WidgetProps) {
      return (
        <InputWidgetBase
          inputType="text"
          inputAddon={<i className="fa fa-paragraph" />}
          {...props}
        />
      );
    }